import os
from datetime import *

def main():
  """ Mail-merge program to create a folder of customized form-letters for
      each customer. """
  setMediaFolder()
  selectedFolder = getMediaFolder()
  os.chdir(selectedFolder)

  custFile = open('customerDataSmall.txt','r')
  customerFields, customerList = generateList(custFile)
  custFile.close()

  formLetterFile = open('formLetter.txt','r')
  formLetterStr = formLetterFile.read()
  formLetterFile.close()
    
  os.mkdir("formLetters")
  os.chdir("formLetters")

  createFormLetters(customerFields, customerList, formLetterStr)

def createFormLetters(customerFields, customerList, formLetterStr):
  customerFields.append("Date")
  todayDate = date.today()
  todayStr = todayDate.strftime("%B %d, %Y") 

  customerNumber = 0
  for customer in customerList:
    formFile = open('customer'+str(customerNumber)+'.txt','w')
    customer.append(todayStr)
    formLetter = createFormLetter(formLetterStr, customerFields,customer)
    formFile.write(formLetter)
    formFile.close()
    customerNumber += 1

def createFormLetter(formLetterStr, customerFields, customer):
  """ Returns the form letter as a single string by replacing the customerFields
      (e.g., <First Name>) in the formLetterStr by the corresponding customer 
      information. """
  startIndex = 0
  formLetter = ""
  while True:
    tagStartIndex = formLetterStr.find('<',startIndex)
    if tagStartIndex == -1:  # -1 indicates not found
      formLetter += formLetterStr[startIndex:]
      break

    formLetter += formLetterStr[startIndex:tagStartIndex]
    
    tagEndIndex = formLetterStr.find('>',tagStartIndex)
    foundTag = formLetterStr[tagStartIndex:tagEndIndex+1]
    
    foundField = foundTag.strip('<>')
    fieldIndex = customerFields.index(foundField)
    
    formLetter += customer[fieldIndex]

    startIndex = tagEndIndex+1
  return formLetter
    

def generateList(custFile):
  """ Reads customer data from custFile and returns a list of fields 
      and a list-of-lists of customers"""
  
  custFields = custFile.readline().strip().split(',')
  custList = []
  for line in custFile:
    custInfoList = line.strip().split(',')
    custList.append(custInfoList)
    
  return custFields, custList

main()